==> keycloak-model-map-18.0.0-sources.jar: org/keycloak/models/map/authorization/entity/MapScopeEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapScopeEntityDelegate implements org.keycloak.models.map.authorization.entity.MapScopeEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapScopeEntity> delegateProvider;
    public MapScopeEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapScopeEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID, id).setId(id);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME, name).setName(name);
    }
    @Override public String getDisplayName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME).getDisplayName();
    }
    @Override public void setDisplayName(String displayName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME, displayName).setDisplayName(displayName);
    }
    @Override public String getIconUri() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI).getIconUri();
    }
    @Override public void setIconUri(String iconUri) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI, iconUri).setIconUri(iconUri);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
}

==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/authorization/entity/MapScopeEntityDelegate.java <==
package org.keycloak.models.map.authorization.entity;
public class MapScopeEntityDelegate implements org.keycloak.models.map.authorization.entity.MapScopeEntity {
    private final org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapScopeEntity> delegateProvider;
    public MapScopeEntityDelegate(org.keycloak.models.map.common.delegate.DelegateProvider<org.keycloak.models.map.authorization.entity.MapScopeEntity> delegateProvider) {
        this.delegateProvider = delegateProvider;
    }
    @Override public boolean isUpdated() {
        return delegateProvider.isUpdated();
    }
    @Override public String getId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID).getId();
    }
    @Override public void setId(String id) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ID, id).setId(id);
    }
    @Override public String getRealmId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.REALM_ID).getRealmId();
    }
    @Override public void setRealmId(String realmId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.REALM_ID, realmId).setRealmId(realmId);
    }
    @Override public String getName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME).getName();
    }
    @Override public void setName(String name) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.NAME, name).setName(name);
    }
    @Override public String getDisplayName() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME).getDisplayName();
    }
    @Override public void setDisplayName(String displayName) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.DISPLAY_NAME, displayName).setDisplayName(displayName);
    }
    @Override public String getIconUri() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI).getIconUri();
    }
    @Override public void setIconUri(String iconUri) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.ICON_URI, iconUri).setIconUri(iconUri);
    }
    @Override public String getResourceServerId() {
        return delegateProvider.getDelegate(true, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID).getResourceServerId();
    }
    @Override public void setResourceServerId(String resourceServerId) {
        delegateProvider.getDelegate(false, org.keycloak.models.map.authorization.entity.MapScopeEntityFields.RESOURCE_SERVER_ID, resourceServerId).setResourceServerId(resourceServerId);
    }
}
